@@ -288,5 +288,5 @@ if __name__ == '__main__':
     if args.outfile == None:
         args.outfile = open(args.fen.replace('/','_') + '.png', 'w')
     
-    im = draw_board(title1=args.title1, title2=args.title2, footnote=args.footnote)
+    im = draw_board(args.fen, title1=args.title1, title2=args.title2, footnote=args.footnote)
     im.save(args.outfile)
\ No newline at end of file
